<!DOCTYPE TS><TS>
<context>
    <name></name>
    <message>
        <source>Mnemosyne</source>
        <translation type="unfinished">Mnemosyne</translation>
    </message>
    <message>
        <source>Removed duplicates: </source>
        <translation type="unfinished">Duplicadas eliminadas: </translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;Aceptar</translation>
    </message>
    <message>
        <source>There are cards with different answers for question:

</source>
        <translation type="unfinished">Hay tarjetas con distintas respuestas a la pregunta: 
</translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation type="unfinished">&amp;Fusionar y editar</translation>
    </message>
    <message>
        <source>&amp;Don&apos;t merge</source>
        <translation type="unfinished">&amp;No fusionar</translation>
    </message>
    <message>
        <source>Done!</source>
        <translation type="unfinished">¡Completado!</translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but it&apos;s getting more familiar.</source>
        <translation type="unfinished">Como 0 pero te empieza a resultar familiar.</translation>
    </message>
    <message>
        <source> Show it less often.</source>
        <translation type="unfinished"> Mostrar con menos frecuencia.</translation>
    </message>
    <message>
        <source>Error in config.py:</source>
        <translation type="unfinished">Error en el archivo config.py:</translation>
    </message>
    <message>
        <source>Error when running plugin:</source>
        <translation type="unfinished">Error al ejecutar el plugin:</translation>
    </message>
    <message>
        <source>Unable to load file.</source>
        <translation type="unfinished">Imposible cargar el archivo.</translation>
    </message>
    <message>
        <source>Invalid file format.</source>
        <translation type="unfinished">Formato de fichero incorrecto.</translation>
    </message>
    <message>
        <source>Unable to save file.</source>
        <translation type="unfinished">Imposible guardar el archivo.</translation>
    </message>
    <message>
        <source>Unable to parse XML:</source>
        <translation type="unfinished">Archivo XML incorrecto:</translation>
    </message>
    <message>
        <source>Unrecognised encoding.</source>
        <translation type="unfinished">Codificación desconocida.</translation>
    </message>
    <message>
        <source>Missing answer on line:</source>
        <translation type="unfinished">Falta la respuesta en la línea:</translation>
    </message>
    <message>
        <source>Unable to load database.
Creating tmp file.</source>
        <translation type="unfinished">Imposible cargar la base de datos.
Creando un archivo temporal.</translation>
    </message>
    <message>
        <source>File exists:</source>
        <translation type="unfinished">El archivo ya existe:</translation>
    </message>
    <message>
        <source>&amp;Overwrite</source>
        <translation type="unfinished">&amp;Sobrescribir</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Cancelar</translation>
    </message>
    <message>
        <source>You don&apos;t remember this card yet.</source>
        <translation type="unfinished">Aún no recuerda esta tarjeta.</translation>
    </message>
    <message>
        <source>You&apos;ve memorised this card now,</source>
        <translation type="unfinished">Acaba de memorizar esta tarjeta.</translation>
    </message>
    <message>
        <source> and will probably remember it for a few days.</source>
        <translation type="unfinished"> y probablemente la recuerde durante unos días.</translation>
    </message>
    <message>
        <source>You have forgotten this card completely.</source>
        <translation type="unfinished">Ha olvidado completamente esta tarjeta.</translation>
    </message>
    <message>
        <source>Barely correct answer. The interval was way too long.</source>
        <translation type="unfinished">Respuesta a duras penas correcta. El intervalo ha sido demasiado largo.</translation>
    </message>
    <message>
        <source>Correct answer, but with much effort.</source>
        <translation type="unfinished">Respuesta correcta pero con mucho esfuerzo.</translation>
    </message>
    <message>
        <source> The interval was probably too long.</source>
        <translation type="unfinished"> El intervalo ha sido probablemente demasiado largo.</translation>
    </message>
    <message>
        <source>Correct answer, with some effort.</source>
        <translation type="unfinished">Respuesta correcta aunque con cierto esfuerzo.</translation>
    </message>
    <message>
        <source> The interval was probably just right.</source>
        <translation type="unfinished"> El intervalo ha sido apropiado.</translation>
    </message>
    <message>
        <source>Correct answer, but without any</source>
        <translation type="unfinished">Respuesta correcta pero sin ningún</translation>
    </message>
    <message>
        <source> difficulties. The interval was probably too short.</source>
        <translation type="unfinished"> esfuerzo. El intervalo ha sido demasiado corto.</translation>
    </message>
</context>
<context>
    <name>AboutDlg</name>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Main author: Peter Bienstman

</source>
        <translation>Autor principal: Peter Bienstman

</translation>
    </message>
    <message>
        <source>More info: http://mnemosyne-proj.sourceforge.net
</source>
        <translation type="obsolete">Más información: http://mnemosyne-proj.sourceforge.net
</translation>
    </message>
    <message>
        <source>More info: http://mnemosyne-proj.org
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AboutFrm</name>
    <message>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
</context>
<context>
    <name>ActivateCategoriesFrm</name>
    <message>
        <source>Activate categories</source>
        <translation>Activar categorías</translation>
    </message>
    <message>
        <source>Select the categories to activate:</source>
        <translation>Seleccione las categorías a activar:</translation>
    </message>
    <message>
        <source>Activate none</source>
        <translation>No activar ninguna</translation>
    </message>
    <message>
        <source>Activate all</source>
        <translation>Activar todas</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+D</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>AddItemsDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;por defecto&gt;</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Abandon current card?</source>
        <translation>¿Desechar esta tarjeta?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Sí</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;No</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Pregunta:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Respuesta:</translation>
    </message>
    <message>
        <source>Written form:</source>
        <translation>Forma escrita:</translation>
    </message>
    <message>
        <source>Translation:</source>
        <translation>Traducción:</translation>
    </message>
    <message>
        <source>Card is already in database.
</source>
        <translation>La tarjeta ya está en la base de datos.</translation>
    </message>
    <message>
        <source>Duplicate not added.</source>
        <translation>Tarjeta duplicada no añadida.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>There are different answers for</source>
        <translation>Hay múltiples respuestas para</translation>
    </message>
    <message>
        <source> this question:

</source>
        <translation> esta pregunta:

</translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation>&amp;Fusionar y editar</translation>
    </message>
    <message>
        <source>&amp;Add as is</source>
        <translation>&amp;Añadir tal cual</translation>
    </message>
    <message>
        <source>&amp;Do not add</source>
        <translation>N&amp;o añadir</translation>
    </message>
</context>
<context>
    <name>AddItemsFrm</name>
    <message>
        <source>Add cards</source>
        <translation>Añadir tarjetas</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Categoría:</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Pregunta:</translation>
    </message>
    <message>
        <source>Pronunciation:</source>
        <translation>Pronunciación:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Respuesta:</translation>
    </message>
    <message>
        <source>Add &amp;vice versa too</source>
        <translation>Añadir también &amp;viceversa</translation>
    </message>
    <message>
        <source>Alt+V</source>
        <translation>Alt+V</translation>
    </message>
    <message>
        <source>Select initial grade:</source>
        <translation>Seleccionar nivel de conocimiento inicial:</translation>
    </message>
    <message>
        <source>&amp;0</source>
        <translation>&amp;0</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>You don&apos;t remember this item yet or forgot it.</source>
        <translation>No recuerda la respuesta o la olvidó.</translation>
    </message>
    <message>
        <source>&amp;1</source>
        <translation>&amp;1</translation>
    </message>
    <message>
        <source>Ctrl+1</source>
        <translation>Ctrl+1</translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but the item is getting more familiar.</source>
        <translation>Como &quot;0&quot; pero se está familiarizando con la respuesta.</translation>
    </message>
    <message>
        <source>&amp;2</source>
        <translation>&amp;2</translation>
    </message>
    <message>
        <source>Ctrl+2</source>
        <translation>Ctrl+2</translation>
    </message>
    <message>
        <source>You&apos;ve memorised this item now, and will probably remember it for a few days.</source>
        <translation>Ha memorizado la respuesta y puede recordarla unos días.</translation>
    </message>
    <message>
        <source>&amp;3</source>
        <translation>&amp;3</translation>
    </message>
    <message>
        <source>Ctrl+3</source>
        <translation>Ctrl+3</translation>
    </message>
    <message>
        <source>Correct answer, but with much effort. The interval was probably too long</source>
        <translation>Respuesta correcta pero con mucho esfuerzo. El programa ha tardado demasiado en preguntarle</translation>
    </message>
    <message>
        <source>&amp;4</source>
        <translation>&amp;4</translation>
    </message>
    <message>
        <source>Ctrl+4</source>
        <translation>Ctrl+4</translation>
    </message>
    <message>
        <source>Correct answer, with some effort. The interval was probably just right.</source>
        <translation>Respuesta correcta con cierto esfuerzo. El programa preguntado en el momento apropiado.</translation>
    </message>
    <message>
        <source>&amp;5</source>
        <translation>&amp;5</translation>
    </message>
    <message>
        <source>Ctrl+5</source>
        <translation>Ctrl+5</translation>
    </message>
    <message>
        <source>Correct answer, but without any difficulties. The interval was probably too short.</source>
        <translation>Respuesta correcta pero sin ningún esfuerzo. El programa ha preguntado demasiado pronto.</translation>
    </message>
    <message>
        <source>Type question and answer, then pick initial grade.</source>
        <translation>Escriba la tarjeta y elija la puntuación inicial.</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation type="obsolete">&amp;Previsualizar</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation>Alt+S</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChangeCategoryFrm</name>
    <message>
        <source>Change category</source>
        <translation>Cambiar categoría</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Categoría:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+D</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
<context>
    <name>ConfigurationFrm</name>
    <message>
        <source>Mnemosyne configuration</source>
        <translation>Configuración</translation>
    </message>
    <message>
        <source>Hover with the mouse over the buttons to get extra information.</source>
        <translation>Mantenga el ratón sobre los botones para obtener más información.</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Aspecto</translation>
    </message>
    <message>
        <source>Set Q/A font</source>
        <translation>Tipo de letra para las preguntas y respuestas</translation>
    </message>
    <message>
        <source>Set the font used when showing single questions and answers</source>
        <translation>Tipo de letra para mostrar solamente preguntas o respuestas</translation>
    </message>
    <message>
        <source>Set list font</source>
        <translation>Tipo de letra de la lista</translation>
    </message>
    <message>
        <source>Set the font used when showing the list of all the cards in the deck</source>
        <translation>Tipo de letra para la lista de todas las tarjetas de la base de datos</translation>
    </message>
    <message>
        <source>Increase size of non-latin characters by</source>
        <translation>Aumentar el tamaño de los caracteres no latinos</translation>
    </message>
    <message>
        <source>Sometimes complex glyphs are hard to read at the default latin font size</source>
        <translation>A veces los caracteres complejos son difíciles de leer con el tipo de letra por defecto</translation>
    </message>
    <message>
        <source>point(s)</source>
        <translation>punto(s)</translation>
    </message>
    <message>
        <source>Log uploading</source>
        <translation>Envío de estadísticas</translation>
    </message>
    <message>
        <source>Upload anonymous logs</source>
        <translation>Enviar estadísticas anónimas</translation>
    </message>
    <message>
        <source>Share anonymous statistics to contribute to memory research</source>
        <translation>Enviar estadísticas anónimas para contribuir al proyecto de investigación sobre la memoria</translation>
    </message>
    <message>
        <source>Duplicate handling</source>
        <translation>Gestión de duplicados</translation>
    </message>
    <message>
        <source>Check for duplicates when adding new cards</source>
        <translation>Comprobar duplicados al añadir nuevas tarjetas</translation>
    </message>
    <message>
        <source>Allow duplicates in different categories</source>
        <translation>Permitir duplicados si están en diferentes categorías</translation>
    </message>
    <message>
        <source>Repetition process</source>
        <translation>Proceso de repetición</translation>
    </message>
    <message>
        <source>Number of grade 0 cards to learn at once:</source>
        <translation type="obsolete">Número de tarjetas con puntuación 0 a aprender de una vez:</translation>
    </message>
    <message>
        <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
        <translation>Aviso: este no es el número de tarjetas de puntuación 0 que desea memorizar *por día*</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>Defaults</source>
        <translation>Reestablecer valores por defecto</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Learn new cards in random order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of grade 0 cards to hold in your hand:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditItemFrm</name>
    <message>
        <source>Edit card</source>
        <translation>Editar tarjeta</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Categoría:</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Pregunta:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Respuesta:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+D</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Previsualizar</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
<context>
    <name>EditItemsDlg</name>
    <message>
        <source>Please wait...</source>
        <translation>Por favor espere...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Previsualizar</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Add vice versa</source>
        <translation>&amp;Añadir &amp;viceversa</translation>
    </message>
    <message>
        <source>S&amp;tatistics</source>
        <translation>Es&amp;tadísticas</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Desechar</translation>
    </message>
    <message>
        <source>&amp;Change category</source>
        <translation>&amp;Cambiar de categoría</translation>
    </message>
    <message>
        <source>Add &amp;vice versa</source>
        <translation>Añadir &amp;viceversa</translation>
    </message>
    <message>
        <source>Add vice versa of these cards?</source>
        <translation>¿Añadir la versión opuesta de estas tarjetas?</translation>
    </message>
    <message>
        <source>Add vice versa of this card?</source>
        <translation>¿Añadir la versión opuesta de esta tarjeta?</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>

This could create duplicates if the vice </source>
        <translation>

Esto puede crear duplicados si la versión opuesta </translation>
    </message>
    <message>
        <source>versas are already present, 
so you might want to run </source>
        <translation>ya está presente.
Tal vez desee ejecutar </translation>
    </message>
    <message>
        <source>clean duplicates&apos; afterwards.</source>
        <translation>eliminar duplicados al acabar.</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Sí</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;No</translation>
    </message>
    <message>
        <source>Grade:</source>
        <translation>Puntuación:</translation>
    </message>
    <message>
        <source>Easiness:</source>
        <translation>Facilidad:</translation>
    </message>
    <message>
        <source>Repetitions:</source>
        <translation>Repeticiones:</translation>
    </message>
    <message>
        <source>Lapses:</source>
        <translation>Olvidos:</translation>
    </message>
    <message>
        <source>Days since last repetition:</source>
        <translation>Días desde la última repetición:</translation>
    </message>
    <message>
        <source>Days until next repetition:</source>
        <translation>Días hasta la próxima repetición:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>Delete these cards?</source>
        <translation>¿Desechar estas tarjetas?</translation>
    </message>
    <message>
        <source>Delete this card?</source>
        <translation>¿Desechar esta tarjeta?</translation>
    </message>
    <message>
        <source>The text you entered was not found.</source>
        <translation>NO se ha encontrado el texto introducido.</translation>
    </message>
    <message>
        <source>&amp;Find again</source>
        <translation>&amp;Buscar de nuevo</translation>
    </message>
    <message>
        <source>F</source>
        <translation>F</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Buscar</translation>
    </message>
    <message>
        <source>Alt+F</source>
        <translation type="obsolete"></translation>
    </message>
</context>
<context>
    <name>EditItemsFrm</name>
    <message>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <source>Answer</source>
        <translation>Respuesta</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Categoría</translation>
    </message>
    <message>
        <source>Edit deck</source>
        <translation>Editar base de datos</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Encontrar</translation>
    </message>
    <message>
        <source>To edit a card, right-click on it.</source>
        <translation>Para editar una tarjeta haga click sobre ella con el botón derecho del ratón.</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation>Alt+S</translation>
    </message>
    <message>
        <source>Alt+F</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>All Files (*);;</source>
        <translation>Todos los archivos (*);;</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
</context>
<context>
    <name>ExportFrm</name>
    <message>
        <source>Export to file</source>
        <translation>Exportar a archivo</translation>
    </message>
    <message>
        <source>File format:</source>
        <translation>Formato de archivo:</translation>
    </message>
    <message>
        <source>File to export to:</source>
        <translation>Fichero al que desea exportar:</translation>
    </message>
    <message>
        <source>&amp;Browse</source>
        <translation>&amp;Buscar</translation>
    </message>
    <message>
        <source>Categories to export:</source>
        <translation>Categorías a exportar:</translation>
    </message>
    <message>
        <source>&amp;Select all</source>
        <translation>&amp;Seleccionar todas</translation>
    </message>
    <message>
        <source>Reset learning data on export</source>
        <translation>Reiniciar datos de aprendizaje en el fichero exportado</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+D</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>ImportDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;por defecto&gt;</translation>
    </message>
    <message>
        <source>All Files (*);;</source>
        <translation>Todos los archivos (*);;</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importar</translation>
    </message>
</context>
<context>
    <name>ImportFrm</name>
    <message>
        <source>Import from file</source>
        <translation>Importar desde archivo</translation>
    </message>
    <message>
        <source>File format:</source>
        <translation>Formato de archivo:</translation>
    </message>
    <message>
        <source>File to import from:</source>
        <translation>Fichero desde el que importar:</translation>
    </message>
    <message>
        <source>&amp;Browse</source>
        <translation>&amp;Buscar</translation>
    </message>
    <message>
        <source>Put cards without category into this category:</source>
        <translation>Poner tarjetas sin categoría en esta cateoría:</translation>
    </message>
    <message>
        <source>Note: all cards will be added to the current database.</source>
        <translation>Aviso: todas las tarjetas se incorporarán a la base de datos actual.</translation>
    </message>
    <message>
        <source>Reset learning data on import</source>
        <translation>Reiniciar datos de aprendizaje de las tarjetas importadas</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+D</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
</context>
<context>
    <name>MainDlg</name>
    <message>
        <source>Mnemosyne databases (*.mem)</source>
        <translation>Bases de datos Mnemosyne (*.mem)</translation>
    </message>
    <message>
        <source>Please wait...</source>
        <translation>Por favor espere...</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Delete current card?</source>
        <translation>¿Desechar esta tarjeta?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Sí</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;No</translation>
    </message>
    <message>
        <source>Returns in </source>
        <translation>Volverá a aparecer en </translation>
    </message>
    <message>
        <source> day(s).</source>
        <translation> día(s).</translation>
    </message>
    <message>
        <source>Next repetition: today.</source>
        <translation>Próxima repetición: hoy.</translation>
    </message>
    <message>
        <source>Next repetition: tomorrow.</source>
        <translation>Próxima repetición: mañana.</translation>
    </message>
    <message>
        <source>Next repetition in </source>
        <translation>Próxima repetición dentro de </translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Pregunta:</translation>
    </message>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;por defecto&gt;</translation>
    </message>
    <message>
        <source>Show &amp;answer</source>
        <translation type="obsolete">Mostrar &amp;respuesta</translation>
    </message>
    <message>
        <source>Learn ahead of schedule</source>
        <translation>Aprender antes de tiempo</translation>
    </message>
    <message>
        <source>Pick days until next repetition:</source>
        <translation>Escoger días hasta la próxima repetición:</translation>
    </message>
    <message>
        <source>Grade your answer:</source>
        <translation>Evalúe su respuesta:</translation>
    </message>
    <message>
        <source>Scheduled: </source>
        <translation>Planificadas:</translation>
    </message>
    <message>
        <source>Not memorised: </source>
        <translation>No memorizadas: </translation>
    </message>
    <message>
        <source>All: </source>
        <translation>Todas: </translation>
    </message>
    <message>
        <source>New</source>
        <translation type="unfinished">Nueva</translation>
    </message>
    <message>
        <source> days.</source>
        <translation type="unfinished"> días.</translation>
    </message>
    <message>
        <source>Show answer</source>
        <translation type="unfinished">Mostrar respuesta</translation>
    </message>
</context>
<context>
    <name>MainFrm</name>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Pregunta:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Respuesta:</translation>
    </message>
    <message>
        <source>Show answer</source>
        <translation>Mostrar respuesta</translation>
    </message>
    <message>
        <source>Grade your answer:</source>
        <translation>Evalúe su respuesta:</translation>
    </message>
    <message>
        <source>&amp;0</source>
        <translation>&amp;0</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>&amp;1</source>
        <translation>&amp;1</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>&amp;2</source>
        <translation>&amp;2</translation>
    </message>
    <message>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <source>&amp;3</source>
        <translation>&amp;3</translation>
    </message>
    <message>
        <source>3</source>
        <translation>3</translation>
    </message>
    <message>
        <source>&amp;4</source>
        <translation>&amp;4</translation>
    </message>
    <message>
        <source>4</source>
        <translation>4</translation>
    </message>
    <message>
        <source>&amp;5</source>
        <translation>&amp;5</translation>
    </message>
    <message>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nueva</translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>A&amp;brir...</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Guardar</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>G&amp;uardar Como...</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Sobre</translation>
    </message>
    <message>
        <source>Add cards</source>
        <translation>Añadir tarjetas</translation>
    </message>
    <message>
        <source>&amp;Add cards</source>
        <translation>&amp;Añadir tarjetas</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <source>Act&amp;ivate categories</source>
        <translation type="obsolete">Act&amp;ivar Categorías</translation>
    </message>
    <message>
        <source>Edit deck</source>
        <translation>Editar base de datos</translation>
    </message>
    <message>
        <source>Edit &amp;deck</source>
        <translation>E&amp;ditar base de datos</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <source>&amp;Import</source>
        <translation>&amp;Importar</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Exportar</translation>
    </message>
    <message>
        <source>Show &amp;toolbar</source>
        <translation>Mostrar barra de herramien&amp;tas</translation>
    </message>
    <message>
        <source>Edit current card</source>
        <translation>Editar esta tarjeta</translation>
    </message>
    <message>
        <source>&amp;Edit current card</source>
        <translation>&amp;Editar esta tarjeta</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Delete current card</source>
        <translation>Desechar esta tarjeta</translation>
    </message>
    <message>
        <source>&amp;Delete current card</source>
        <translation>&amp;Desechar esta tarjeta</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <source>&amp;Clean duplicates</source>
        <translation>&amp;Eliminar duplicados</translation>
    </message>
    <message>
        <source>&amp;Configure Mnemosyne</source>
        <translation>&amp;Configuración</translation>
    </message>
    <message>
        <source>Getting started</source>
        <translation>Comenzar</translation>
    </message>
    <message>
        <source>&amp;Getting started</source>
        <translation>&amp;Comenzar</translation>
    </message>
    <message>
        <source>Down, Down</source>
        <translation>Abajo, Abajo</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Seleccionar</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>Volver</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>Espacio</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Show statistics</source>
        <translation>Mostrar estadísticas</translation>
    </message>
    <message>
        <source>Show s&amp;tatistics</source>
        <translation>Mostrar es&amp;tadísticas</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Tip of the day</source>
        <translation>Consejo del día</translation>
    </message>
    <message>
        <source>&amp;Tip of the day</source>
        <translation>&amp;Consejo del día</translation>
    </message>
    <message>
        <source>Main toolbar (Mnemosyne)</source>
        <translation>Barra de herramientas principal</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Archivo</translation>
    </message>
    <message>
        <source>&amp;Deck</source>
        <translation>&amp;Base de datos</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Configuración</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ayuda</translation>
    </message>
    <message>
        <source>Activate cate&amp;gories</source>
        <translation>Act&amp;ivar Categorías</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
</context>
<context>
    <name>PreviewItemDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;por defecto&gt;</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Pregunta:</translation>
    </message>
</context>
<context>
    <name>PreviewItemFrm</name>
    <message>
        <source>Preview card</source>
        <translation>Previsualizar tarjeta</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Pregunta:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Respuesta:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+D</translation>
    </message>
</context>
<context>
    <name>ProductTourFrm</name>
    <message>
        <source>Getting started</source>
        <translation>Comenzando</translation>
    </message>
    <message>
        <source>Greetings!

I am Mnemosyne, a type of butterfly named after the Greek goddess of Memory. 

I can make it more efficient for you to memorise and remember answers to questions, by helping you focus on the cards you&apos;re most likely to forget and by not wasting your time on things you know well.

For that, I&apos;ll decide when to ask you the questions, and you&apos;ll need to rate how well you remember the answers.

Let&apos;s look at the meaning of these ratings now.</source>
        <translation>¡Bienvenido!

Mnemosyne toma su nombre de un tipo de mariposa, cuyo nombre proviene a su vez de la diosa griega de la memoria.

El objetivo del programa es hacer más eficiente el proceso de memorizar la respuesta a preguntas. Mnemosyne le hace repasar más a menudo la información que más le cuesta recordar sin desperdiciar su tiempo con cosas que ya sabe.

Usted debe evaluar su conocimiento de las preguntas atendiendo al siguiente criterio:</translation>
    </message>
    <message>
        <source>Introduction</source>
        <translation>Introducción</translation>
    </message>
    <message>
        <source>Grades range from 0 to 5.

Grades 0 and 1 are used if you don&apos;t know the answer yet, or if you have forgotten it. A card with grade 1 is starting to get more familiar than one with grade 0, and will be repeated less often.

I will keep on asking you these questions until you give them a grade 2 or higher (the exact grade doesn&apos;t matter). Grade 2 basically means that you think you&apos;ll be able to remember the card for at least one or two days. It signals the transition between short and long term memory.

I will schedule this card at some future date, when I think you&apos;ll still be able to remember it with some effort, without having forgotten it completely. This is the most efficient for the learning process.</source>
        <translation>Las puntuaciones van de 0 a 5.

Las puntuaciones 0 y 1 se utilizan cuando todavía no conoce la respuesta. Utilice el 0 cuando no tenga ninguna idea y el 1 cuando aun sin saberla le resulte familiar. Mnemosyne continuará mostrándole estas preguntas hasta que las asigne una puntuación superior a 1.

Asigne la puntuación 2 cuando piense que podrá recordar la respuesta unos días. Esto marca el paso de memoria reciente a memoria lejana.

Mnemosyne volverá a mostrarle esta tarjeta cuando estime que usted pueda recordarla con cierto esfuerzo. Esta es la forma más eficiente para el proceso de memorización.</translation>
    </message>
    <message>
        <source>Grades 0-2</source>
        <translation>Puntuaciones 0-2</translation>
    </message>
    <message>
        <source>If in the future I ask you the question too soon, and you&apos;re able to remember it without any effort, you rate the card a 5. I&apos;ll take this into account by waiting a lot longer before asking you this question again.

If I get it just right, so that you remember it, albeit with some effort, you use grade 4.

If on the other hand it takes you significant effort to remember the answer, and you think I&apos;ve waited too long to ask you this question, then rate the card 3.

If you fail to remember it altogether, rate it either 0 or 1, and I&apos;ll keep on asking you this question until you think you&apos;ll be able to remember it again for a few days.</source>
        <translation>Si en el futuro Mnemosyne le hace la pregunta demasiado pronto y puede recordarla sin esfuerzo, asigne una puntuación de 5.

Si puede recordarla con un ligero esfuerzo, asigne 4.

Si tiene que hacer un esfuerzo considerable, asigne 3.

Si no la recuerda, asigne 0 ó 1 y el programa insistirá sobre esta tarjeta hasta que pueda recordarla unos días.</translation>
    </message>
    <message>
        <source>Grades 3-5</source>
        <translation>Puntuaciones 3-5</translation>
    </message>
    <message>
        <source>If you&apos;re into statistics, I can keep detailed logs of your revisions.

Not only that, but if you want, I can upload transparently a completely anonymous version of these logs to a central site for analysis, so that you can help making me better. In this way, you also contribute to scientific research on long-term memory.

Uncheck the following box if you do not want to do this.</source>
        <translation>Si le interesan, el programa puede guardar estadísticas detalladas de sus sesiones de estudio.

Si da su consentimiento, estas estadísticas se enviarán de forma completamente anónima para su posterior análisis. Esto ayudará a mejorar futuras versiones del programa. Además contribuirá a la investigación científica de la memoria lejana.

Desactive la siguiente opción si no está de acuerdo.</translation>
    </message>
    <message>
        <source>Upload anonymous logs</source>
        <translation>Enviar estadísticas anónimas</translation>
    </message>
    <message>
        <source>(You can always change this setting later using the &apos;Configure Mnemosyne&apos; menu option.)</source>
        <translation>(Puede cambiar esta selección más adelante el el menú &quot;Configurar Mnemosyne&quot;)</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Estadísticas</translation>
    </message>
    <message>
        <source>Now you&apos;re ready to start!
&lt;p&gt;
Add new cards by clicking on the icon with the &apos;plus&apos; sign in the top left.
&lt;p&gt;
Remember, there is no need to worry about saving your work, I will do so automatically.
&lt;p&gt;
For best results, I suggest you do your revisions every day, although I&apos;ll try to cope as best I can if you postpone your revisions or if you want to learn ahead of time.
&lt;p&gt;
For more documentation, see &lt;a href =&quot;http://mnemosyne-proj.sourceforge.net&quot;&gt;http://www.mnemosyne-proj.sourceforge.net&lt;/a&gt;
&lt;p&gt;
Happy learning!</source>
        <translation type="obsolete">¡Ya puede comenzar!
&lt;p&gt;
Añada nuevas tarjetas pinchando en el icono con el signo &quot;más&quot;.
&lt;p&gt;
No tiene que preocuparse por guardar la sesión, se guarda automáticamente.
&lt;p&gt;
Para obtener mejores resultados, le sugerimos hacer revisiones diarias. En cualquier caso el programa se adaptará lo mejor que pueda a sus hábitos de estudio.
&lt;p&gt;
Puede obtener más información en &lt;a href =&quot;http://mnemosyne-proj.sourceforge.net&quot;&gt;http://www.mnemosyne-proj.sourceforge.net&lt;/a&gt;
&lt;p&gt;
¡Buen aprendizaje!</translation>
    </message>
    <message>
        <source>Ready to start</source>
        <translation>Comenzar</translation>
    </message>
    <message>
        <source>Now you&apos;re ready to start!
&lt;p&gt;
Add new cards by clicking on the icon with the &apos;plus&apos; sign in the top left.
&lt;p&gt;
Remember, there is no need to worry about saving your work, I will do so automatically.
&lt;p&gt;
For best results, I suggest you do your revisions every day, although I&apos;ll try to cope as best I can if you postpone your revisions or if you want to learn ahead of time.
&lt;p&gt;
For more documentation, see http://www.mnemosyne-proj.sourceforge.net.
&lt;p&gt;
Happy learning!</source>
        <translation type="unfinished">¡Ya puede comenzar!
&lt;p&gt;
Añada nuevas tarjetas pinchando en el icono con el signo &quot;más&quot;.
&lt;p&gt;
No tiene que preocuparse de guardar la sesión. Se hará automáticamente.
&lt;p&gt;
Para obtener mejores resultados, le sugerimos hacer revisiones diarias. En cualquier caso el programa se adaptará lo mejor que pueda a sus hábitos de estudio.
&lt;p&gt;
Puede obtener más información en http://www.mnemosyne-proj.sourceforge.net.
&lt;p&gt;
¡Buen aprendizaje!</translation>
    </message>
</context>
<context>
    <name>QTextEdit2</name>
    <message>
        <source>Insert &amp;image</source>
        <translation>Añadir &amp;Imagen</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Insert &amp;sound</source>
        <translation>Añadir &amp;Sonido</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>&amp;3-sided input</source>
        <translation>Tarjeta de &amp;3 entradas</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>Archivos de imagen</translation>
    </message>
    <message>
        <source>Insert image</source>
        <translation>Insertar imagen</translation>
    </message>
    <message>
        <source>Sound files</source>
        <translation>Archivos de sonido</translation>
    </message>
    <message>
        <source>Insert sound</source>
        <translation>Insertar sonido</translation>
    </message>
</context>
<context>
    <name>StatisticsDlg</name>
    <message>
        <source>Scheduled cards for the next days:

</source>
        <translation type="obsolete">Tarjetas planificadas para los próximos días:

</translation>
    </message>
    <message>
        <source>In</source>
        <translation>En</translation>
    </message>
    <message>
        <source>day(s) :</source>
        <translation>día(s):</translation>
    </message>
    <message>
        <source>Number of cards with the following grades:

</source>
        <translation>Número de tarjetas con la siguiente puntuación:

</translation>
    </message>
    <message>
        <source>Grade</source>
        <translation>Puntuación</translation>
    </message>
    <message>
        <source>No current card.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grade:</source>
        <translation type="unfinished">Puntuación:</translation>
    </message>
    <message>
        <source>Easiness:</source>
        <translation type="unfinished">Facilidad:</translation>
    </message>
    <message>
        <source>Repetitions:</source>
        <translation type="unfinished">Repeticiones:</translation>
    </message>
    <message>
        <source>Lapses:</source>
        <translation type="unfinished">Olvidos:</translation>
    </message>
    <message>
        <source>Days since last repetition:</source>
        <translation type="unfinished">Días desde la última repetición:</translation>
    </message>
    <message>
        <source>Days until next repetition:</source>
        <translation type="unfinished">Días hasta la próxima repetición:</translation>
    </message>
    <message>
        <source>Scheduled cards for next week:

</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StatisticsFrm</name>
    <message>
        <source>Category</source>
        <translation>Categoría</translation>
    </message>
    <message>
        <source>Cards</source>
        <translation>Tarjetas</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Estadísticas</translation>
    </message>
    <message>
        <source>Schedule</source>
        <translation>Plan</translation>
    </message>
    <message>
        <source>Grades</source>
        <translation>Puntuaciones</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Categorías</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;Aceptar</translation>
    </message>
    <message>
        <source>Current card</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TipDlg</name>
    <message>
        <source>For optimal results, it&apos;s best to do your repetitions every day.</source>
        <translation>Para obtener mejores resultados, se recomienda usar el programa a diario.</translation>
    </message>
    <message>
        <source>If you&apos;ve been away for a few days, don&apos;t worry about your backlog. Do as many cards as you feel like to catch up, the rest will be automatically rescheduled to the future.</source>
        <translation>Si se ausenta durante unos días, no se preocupe por las tarjetas acumuladas. Repase tantas como quiera y las restantes se asignarán a otro día.</translation>
    </message>
    <message>
        <source>The &apos;number of grade 0 cards to learn at once&apos; setting determines how many new cards you are trying to learn at the same time. It does &lt;b&gt;not&lt;/b&gt; tell you how many new cards you need to learn per day. You are the judge of that: you can learn more cards or less cards, depending on how you feel.</source>
        <translation>La opción &quot;Número de tarjetas con puntuación 0 a aprender de una vez&quot; no determina el número de tarjetas nuevas que aprende al día. Eso debe valorarlo usted mismo.</translation>
    </message>
    <message>
        <source>In summary, try to do your repetitions every day, but don&apos;t worry too much about getting the &apos;scheduled&apos; counter to zero, and certainly not about getting the &apos;Not memorised&apos; counter to zero.</source>
        <translation>Resumiendo: intente practicar a diario, pero no se preocupe demasiado por dejar el contador de &quot;planificadas&quot; a cero. Mucho menos de dejar a cero el de &quot;no memorizadas&quot;.</translation>
    </message>
    <message>
        <source>Grade 1 cards are different from grade 0 cards in the sense that they show up less often and are not subject to the &apos;number of grade 0 cards to learn at once&apos; setting.</source>
        <translation>La diferencia entre las tarjetas con puntuaciones 0 y 1  es que las segundas aparecen con menor frecuencia y no se ven afectadas por la opción &quot;número de tarjetas de puntuación 0 para aprender de una vez&quot;.</translation>
    </message>
    <message>
        <source>You can use keyboard shortcuts to do your repetitions. Enter, Return or Space stand for the default action (&apos;Show answer&apos; or &apos;grade 4&apos;). The number keys can be used for grading.</source>
        <translation>Durante su uso puede controlar el programa únicamente con el teclado. El retorno de carro y la barra espaciadora ejecutan la acción por defecto (&quot;Mostrar respuesta&quot; o &quot;Puntuación 4&quot;). Las teclas numéricas pueden usarse para puntuar.</translation>
    </message>
    <message>
        <source>You can select the categories you wish to study in the &apos;Activate categories&apos; menu option.</source>
        <translation>Puede seleccionar las categorías que quiere estudiar en el menú &quot;Activar categorías&quot;.</translation>
    </message>
    <message>
        <source>It is recommended to put all your cards in a single database and use categories to organise them. Using &apos;Activate categories&apos; is much more convenient than have to load and unload several databases.</source>
        <translation>Se recomienda que ponga todas sus tarjetas en una base de datos y que use las categorías para organizarlas. Esto es más simple que manejar varias colecciones.</translation>
    </message>
    <message>
        <source>You can import cards in a wide variety of formats: tab delimited txt files, Supermemo files, ... .</source>
        <translation>Puede importar tarjetas en varios formatos: ficheros de texto delimitados por tabuladores, archivos del programa Supermemo, ...</translation>
    </message>
    <message>
        <source>If you have cards in Word or Excel, export them to tab delimited txt files with UTF-8 unicode encoding to be able to import them into Mnemosyne.</source>
        <translation>Si tiene tarjetas en Word o Excel, expórtelas a un archivo delimitado por tabuladores con codificación unicode UTF-8 para poder importarlas en Mnemosyne.</translation>
    </message>
    <message>
        <source>If you want to print out your cards, export them to a txt file which you can then print from your favourite Word processor.</source>
        <translation>Si quiere imprimir sus tarjetas, expórtelas como un archivo de texto e imprímalas con su editor de texto preferido.</translation>
    </message>
    <message>
        <source>You can share your cards with someone else by exporting them to XML and choosing the &apos;Reset learning data&apos; option on export.</source>
        <translation>Puede compartir sus tarjetas exportándolas a XML y seleccionando &quot;Reiniciar datos de aprendizaje en el fichero exportado&quot;.</translation>
    </message>
    <message>
        <source>If you study a foreign language with a different script, the default font size is sometimes a bit small. If you want to increase the size of these characters but keep the size of English text, use the &apos;increase size of non-latin characters by X points&apos; option.</source>
        <translation>Si estudia un idioma con un juego de caracteres diferentes el tamaño de letra normal puede resultar demasiado pequeño. Puede incrementar el tamaño de estos caracteres manteniendo el de los occidentales con la opción &quot;Incremento de los caracteres no latinos&quot;.</translation>
    </message>
    <message>
        <source>You can add images and sounds to your cards. Right-click on the question or answer field when editing a card to bring up a pop-up menu to do so.</source>
        <translation>Puede añadir imágenes y sonidos a sus tarjetas. Haga click con el botón derecho en el cuadro de texto mientras edita una tarjeta para ver el menu correspondiente.</translation>
    </message>
    <message>
        <source>It is recommended to keep your sound and image files inside your .mnemosyne directory. That way, it&apos;s easier to transfer your data between different computers.</source>
        <translation>Se recomienda que guarde sus archivos de imagen y sonido en su directorio .mnemosyne. Así es más fácil transferir datos entre computadoras.</translation>
    </message>
    <message>
        <source>When adding a three-sided card, two regular cards will be created. One with as question the written form and as answer the pronunciation and the translation, and one with as question the translation and as answer the written form and the pronunciation.</source>
        <translation>Cuando añada una tarjeta de tres lados, se crearán dos tarjetas normales. Una con la forma escrita como pregunta y la pronunciación y significado como respuesta y otra con el significado como pregunta y la forma escrita y la pronunciación como respuesta.</translation>
    </message>
    <message>
        <source>You can use basic HTML tags in your cards to control their appearance.</source>
        <translation>Puede utilizar etiquetas HTML básicas para controlar la apariencia de sus tarjetas.</translation>
    </message>
    <message>
        <source>Mnemosyne can use LaTeX to render mathematical formulas, e.g. &lt;$&gt;x^2+y^2=z^2&lt;/$&gt;. (For this, you need LaTeX and dvipng installed.)</source>
        <translation>Mnemosyne puede usar LaTeX para mostrar fórmulas matemáticas. Por ejemplo: &lt;$&gt;x^2+y^2=z^2&lt;/$&gt;. Para esto necesita instalar LaTeX y dvipng.</translation>
    </message>
    <message>
        <source>The best way to backup your data is to copy your .mnemosyne directory (if you follow the recommended procedure to keep all your files there) and move it to a different drive. Mnemosyne keeps automatic XML-based backups in .mnemosyne/backups, but that won&apos;t help you if that drive dies... </source>
        <translation>La mejor manera de hacer una copia de seguridad de sus datos es hacer una copia de su directorio .mnemosyne completo (si ha seguido la recomendación de guardar ahí todos sus archivos) en un disco duro diferente, una llave USB o algún lugar de Internet. Mnemosyne guarda automáticamente copias de seguridad en el directorio .mnemosyne/backups, pero si falla su disco duro no servirán de mucho.</translation>
    </message>
    <message>
        <source>You can run Mnemosyne from a USB key. Copy C:\Program Files\Mnemosyne to your USB key, and then copy the .mnemosyne directory from your home directory to inside the Mnemosyne directory on the USB key.</source>
        <translation>Puede ejecutar Mnemosyne desde una llave USB. Para ello copie C:\Archivos de Programa\Mnemosyne a la llave USB y luego copie el directorio .mnemosyne desde su directorio de usuario al directorio Mnemosyne de la llave USB.</translation>
    </message>
    <message>
        <source>If you use Mnemosyne on multiple computers, there is a handy tool called Unison to help you synchronise your data. See the Mnemosyne website for more information.</source>
        <translation>Si utiliza Mnemosyne en varios ordenadores el programa Unison puede ayudarle a sincronizar sus datos entre los mismos. Para más información visite la web de Mnemosyne.</translation>
    </message>
    <message>
        <source>You can sort the cards in the &apos;Edit Deck&apos; dialog by answer or by category by clicking on the corresponding column title. Clicking again changes the sort order.</source>
        <translation>Puede ordenar las tarjetas en el cuadro de edición, haciendo click en el correspondiente título de columna. Haga click de nuevo para invertir el orden.</translation>
    </message>
    <message>
        <source>If you want more fine-grained control over LaTeX&apos;s behaviour, see the explanation of the &lt;$$&gt;...&lt;/$$&gt; and &lt;latex&gt;...&lt;/latex&gt; tags on Mnemosyne&apos;s website.</source>
        <translation>Si desea mayor control sobre el comportamiento de LaTeX, consulte las explicaciones detalladas en la página web de Mnemosyne.</translation>
    </message>
    <message>
        <source>Advanced users can customise more of Mnemosyne by editing the config.py file in their .mnemosyne directory. They can also install plugins to customise Mnemosyne even further.</source>
        <translation>Los usuarios avanzados pueden personalizar el programa editando el fichero config.py o instalando plugins.</translation>
    </message>
</context>
<context>
    <name>TipFrm</name>
    <message>
        <source>Tip of the day</source>
        <translation>Consejo del día</translation>
    </message>
    <message>
        <source>&lt;b&gt;Did you know...?&lt;/b&gt;</source>
        <translation>&lt;b&gt;¿Sabía que...?&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&amp;Show tips on startup</source>
        <translation>&amp;Mostrar consejos al inicio</translation>
    </message>
    <message>
        <source>Alt+S</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation>&amp;Anterior</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Siguiente</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation>Alt+S</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
<context>
    <name>qApp</name>
    <message>
        <source>Error in config.py:</source>
        <translation type="obsolete">Error en el archivo config.py:</translation>
    </message>
    <message>
        <source>Error when running plugin:</source>
        <translation type="obsolete">Error al ejecutar el plugin:</translation>
    </message>
    <message>
        <source>Unable to load file.</source>
        <translation type="obsolete">Imposible cargar el archivo.</translation>
    </message>
    <message>
        <source>Invalid file format.</source>
        <translation type="obsolete">Formato de fichero incorrecto.</translation>
    </message>
    <message>
        <source>Unable to save file.</source>
        <translation type="obsolete">No se ha podido guardar el archivo.</translation>
    </message>
    <message>
        <source>Unable to parse XML:</source>
        <translation type="obsolete">Archivo XML incorrecto:</translation>
    </message>
    <message>
        <source>Unrecognised encoding.</source>
        <translation type="obsolete">Codificación desconocida.</translation>
    </message>
    <message>
        <source>Missing answer on line:</source>
        <translation type="obsolete">Falta la respuesta en la línea:</translation>
    </message>
    <message>
        <source>Unable to load database.
Creating tmp file.</source>
        <translation type="obsolete">No se ha podido cargar la base de datos.
Creando archivo temporal.</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation type="obsolete">Mnemosyne</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;Aceptar</translation>
    </message>
    <message>
        <source>File exists:</source>
        <translation type="obsolete">El archivo ya existe:</translation>
    </message>
    <message>
        <source>&amp;Overwrite</source>
        <translation type="obsolete">&amp;Sobrescribir</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">&amp;Cancelar</translation>
    </message>
    <message>
        <source>Removed duplicates: </source>
        <translation type="obsolete">Duplicados eliminadas: </translation>
    </message>
    <message>
        <source>There are cards with different answers for question:

</source>
        <translation type="obsolete">Hay tarjetas con distintas respuestas a la pregunta: 
</translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation type="obsolete">&amp;Fusionar y editar</translation>
    </message>
    <message>
        <source>&amp;Don&apos;t merge</source>
        <translation type="obsolete">&amp;No fusionar</translation>
    </message>
    <message>
        <source>Done!</source>
        <translation type="obsolete">¡Hecho!</translation>
    </message>
    <message>
        <source>You don&apos;t remember this card yet.</source>
        <translation type="obsolete">Aun no recuerda esta tarjeta.</translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but it&apos;s getting more familiar.</source>
        <translation type="obsolete">Igual que 0 pero se le está volviendo familiar.</translation>
    </message>
    <message>
        <source> Show it less often.</source>
        <translation type="obsolete"> Mostrar con menos frecuencia.</translation>
    </message>
    <message>
        <source>You&apos;ve memorised this card now,</source>
        <translation type="obsolete">Acaba de memorizar esta tarjeta</translation>
    </message>
    <message>
        <source> and will probably remember it for a few days.</source>
        <translation type="obsolete"> y probablemente la recordará unos días.</translation>
    </message>
    <message>
        <source>You have forgotten this card completely.</source>
        <translation type="obsolete">Ha olvidado esta tarjeta completamente.</translation>
    </message>
    <message>
        <source>Barely correct answer. The interval was way too long.</source>
        <translation type="obsolete">Respuesta a duras penas correcta. El intervalo ha sido demasiado largo.</translation>
    </message>
    <message>
        <source>Correct answer, but with much effort.</source>
        <translation type="obsolete">Respuesta correcta pero con mucho esfuerzo.</translation>
    </message>
    <message>
        <source> The interval was probably too long.</source>
        <translation type="obsolete"> El intervalo ha sido probablemente demasiado largo.</translation>
    </message>
    <message>
        <source>Correct answer, with some effort.</source>
        <translation type="obsolete">Respuesta correcta pero con cierto esfuerzo.</translation>
    </message>
    <message>
        <source> The interval was probably just right.</source>
        <translation type="obsolete"> El intervalo ha sido apropiado.</translation>
    </message>
    <message>
        <source>Correct answer, but without any</source>
        <translation type="obsolete">Respuesta correcta pero sin ningún</translation>
    </message>
    <message>
        <source> difficulties. The interval was probably too short.</source>
        <translation type="obsolete">esfuerzo. El intervalo fue muy corto.</translation>
    </message>
    <message>
        <source> days.</source>
        <translation type="obsolete"> días.</translation>
    </message>
</context>
</TS>
